netapp_ontap.models.volume_efficiency API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.volume_efficiency`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class VolumeEfficiencySchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the VolumeEfficiency object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `application_io_size GET POST PATCH`

    Block size to use by compression. Valid for POST.

    Valid choices:

    - 8k
    - auto
  `compaction GET POST PATCH`

    The system can be enabled/disabled compaction.
    inline ‐ Data will be compacted first and written to the volume.
    none ‐ None
    mixed ‐ Read only field for FlexGroups, where some of the constituent volumes are compaction enabled and some are disabled.

    Valid choices:

    - inline
    - none
    - mixed
  `compression GET POST PATCH`

    The system can be enabled/disabled compression.
    inline ‐ Data will be compressed first and written to the volume.
    background ‐ Data will be written to the volume and compressed later.
    both ‐ Inline compression compresses the data and write to the volume, background compression compresses only the blocks on which inline compression is not run.
    none ‐ None
    mixed ‐ Read only field for FlexGroups, where some of the constituent volumes are compression enabled and some are disabled.

    Valid choices:

    - inline
    - background
    - both
    - none
    - mixed
  `cross_volume_dedupe GET POST PATCH`

    The system can be enabled/disabled cross volume dedupe. it can be enabled only when dedupe is enabled.
    inline ‐ Data will be cross volume deduped first and written to the volume.
    background ‐ Data will be written to the volume and cross volume deduped later.
    both ‐ Inline cross volume dedupe dedupes the data and write to the volume, background cross volume dedupe dedupes only the blocks on which inline dedupe is not run.
    none ‐ None
    mixed ‐ Read only field for FlexGroups, where some of the constituent volumes are cross volume dedupe enabled and some are disabled.

    Valid choices:

    - inline
    - background
    - both
    - none
    - mixed
  `dedupe GET POST PATCH`

    The system can be enabled/disabled dedupe.
    inline ‐ Data will be deduped first and written to the volume.
    background ‐ Data will be written to the volume and deduped later.
    both ‐ Inline dedupe dedupes the data and write to the volume, background dedupe dedupes only the blocks on which inline dedupe is not run.
    none ‐ None
    mixed ‐ Read only field for FlexGroups, where some of the constituent volumes are dedupe enabled and some are disabled.

    Valid choices:

    - inline
    - background
    - both
    - none
    - mixed
  `policy GET POST PATCH`

    The policy field of the volume_efficiency.

  `schedule GET`

    Schedule associated with volume.